braindecode.datautil.create_fixed_length_windows
================================================

.. currentmodule:: braindecode.datautil

.. autofunction:: create_fixed_length_windows

.. include:: braindecode.datautil.create_fixed_length_windows.examples

.. raw:: html

    <div style='clear:both'></div>